'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');
// 定时任务表
const schedule = {
  table: {
    type: String,
    required: true,
    maxLength: 200,
    field: { label: '表', filter: 'select', required: true },
  },
  column: {
    type: String,
    required: true,
    maxLength: 200,
    field: { label: '监控内容', filter: true, required: true },
  },
  number: {
    type: String,
    maxLength: 200,
    field: { label: '时间数', filter: true, required: true },
  },
  unit: {
    type: String,
    maxLength: 200,
    field: { label: '时间单位', filter: true, required: true },
  },
  user_ids: {
    type: Array,
    required: true,
    field: { label: '要发送的用户id' },
  },
  status: {
    type: String,
    maxLength: 200,
    default: '0',
    field: {
      label: '状态',
      filter: 'select',
      type: 'select',
      format: (i => (i === '0' ? '使用' : '禁用')).toString(),
      list: [
        { label: '使用', value: '0' },
        { label: '禁用', value: '1' },
      ],
    },
  }, // 状态:0=>使用;1禁用
};

const schema = new Schema(schedule, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.plugin(metaPlugin);

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('Schedule', schema, 'schedule');
};
